Module attr

Module attr 

Vertex and instance attribute types.

This module defines the DataType trait (implemented for all primitive numeric types and their fixed-size arrays), the ATTRInfo / ATTRName descriptors, and a set of concrete attribute containers:

Structs

ATTRInfo
Describes a single vertex or instance attribute: name, GL type, byte size, element count.
ColATTR
CustomATTR
User-defined vertex or instance attribute with arbitrary byte data.
IndATTR
NrmATTR
Pos2DATTR
Pos3DATTR
Rot2DATTR
Rot3DATTR
Scale2DATTR
Scale3DATTR
UVMATTR

Enums

ATTRName
Discriminated name for a vertex or instance attribute.

Traits

DataType
Trait for types that can be used as vertex or instance attribute data.