Module instance

Module instance 

Structs

InstanceBuffer
A GPU buffer of interleaved per-instance attributes with a CPU-side mirror for random access.
InstanceDesc2D
Descriptor for preparing 2D instance data before uploading it to the GPU.
InstanceDesc3D
Descriptor for preparing 3D instance data before uploading it to the GPU.