pub struct CustomATTR {
pub data: Vec<u8>,
pub info: ATTRInfo,
}Expand description
User-defined vertex or instance attribute with arbitrary byte data.
Create via CustomATTR::empty or CustomATTR::from parameterised by a
DataType, then push elements with CustomATTR::push.
Example
use optic_render::asset::attr::CustomATTR;
let mut attr = CustomATTR::empty::<u32>("bone_ids");
attr.push(0u32);
attr.push(1u32);Fields
data: Vec<u8>info: ATTRInfoImplementations
Sourceimpl CustomATTR
impl CustomATTR
Sourcepub fn empty<D: DataType>(name: &str) -> Self
pub fn empty<D: DataType>(name: &str) -> Self
Creates an empty custom attribute with the given name and data type.
Sourcepub fn from<D: DataType>(name: &str, vec: Vec<D>) -> Self
pub fn from<D: DataType>(name: &str, vec: Vec<D>) -> Self
Creates a custom attribute from a Vec of typed elements.
Sourcepub fn from_array<D: DataType + Clone>(name: &str, array: &[D]) -> Self
pub fn from_array<D: DataType + Clone>(name: &str, array: &[D]) -> Self
Creates a custom attribute from a slice of typed elements.