Structs
- Instance
Buffer - A GPU buffer of interleaved per-instance attributes with a CPU-side mirror for random access.
- Instance
Desc2D - Descriptor for preparing 2D instance data before uploading it to the GPU.
- Instance
Desc3D - Descriptor for preparing 3D instance data before uploading it to the GPU.